===========
sxm-discord
===========

.. image:: https://readthedocs.org/projects/sxm-discord/badge/?version=latest
    :target: https://sxm-discord.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://github.com/AngellusMortis/sxm-discord/actions/workflows/ci.yml/badge.svg
    :target: https://github.com/AngellusMortis/sxm-discord/actions/workflows/ci.yml
    :alt: CI Status

.. image:: https://api.codeclimate.com/v1/badges/0c0e1c828d5bd64fe4a8/maintainability
    :target: https://codeclimate.com/github/AngellusMortis/sxm-discord/maintainability
    :alt: Maintainability

.. image:: https://pypip.in/v/sxm-discord/badge.png
    :target: https://pypi.org/project/sxm-discord/
    :alt: Latest PyPI version


.. warning:: Designed for PERSONAL USE ONLY

    ``sxm-discord`` is a 100% unofficial project and you use it at your own risk.
    It is designed to be used for personal use with a small number of users
    listening to it at once. Similar to playing music over a speakers from the
    radio directly. Using ``sxm-discord`` in any corporate setting, to
    attempt to pirate music, or to try to make a profit off your subscription
    may result in you getting in legal trouble.


A Discord bot that will play SXM radio stations. ``sxm-discord`` is a player
class for `sxm-player`_.


* Free software: MIT license
* Documentation: https://sxm-discord.readthedocs.io.

.. _sxm-player: https://github.com/AngellusMortis/sxm-player

Features
--------

* Runs a Discord bot that can play SXM channel
* Can ad-hoc playback any saved archives of songs/shows
* Can create an infinite random playlist of archived songs

Credits
-------

This package was created with Cookiecutter_ and the
`audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
